@@ -17,15 +17,14 @@ Custom date/time input handlers for Parameters.
 from __future__ import annotations
 
 from abc import ABC, abstractmethod
-from calendar import day_name, day_abbr, month_name, month_abbr
-from datetime import datetime, date, time, timedelta
+from calendar import day_abbr, day_name, month_abbr, month_name
+from datetime import date, datetime, time, timedelta
 from enum import Enum
 from locale import LC_ALL, setlocale
 from threading import RLock
-from typing import Union, Iterator, Collection, Sequence, Optional, TypeVar, Type, Literal, overload
-from typing import Tuple, Dict
+from typing import Collection, Iterator, Literal, Optional, Sequence, Type, TypeVar, Union, overload
 
-from ..typing import T, Bool, Locale, TimeBound
+from ..typing import Bool, Locale, T, TimeBound
 from ..utils import MissingMixin
 from .base import InputType
 from .exceptions import InputValidationError, InvalidChoiceError
@@ -56,7 +55,7 @@ class different_locale:
 
     def __enter__(self):
         self._lock.acquire()
-        if not (locale := self.locale):
+        if not self.locale:
             return
         # locale.getlocale does not support LC_ALL, but `setlocale(LC_ALL)` with no locale to set will return a str
         # containing all of the current locale settings as `key1=val1;key2=val2;...;keyN=valN`
@@ -65,7 +64,7 @@ class different_locale:
         # to remain set to `English_United States.1252` on Windows 10, which resulted in incorrectly encoded results.
         # Using f'LC_CTYPE={locale};LC_TIME={locale}' seemed cleaner than setting LC_ALL in its entirety, but it
         # resulted in `locale.Error: unsupported locale setting` on Ubuntu/WSL.
-        setlocale(LC_ALL, locale)
+        setlocale(LC_ALL, self.locale)
 
     def __exit__(self, exc_type, exc_val, exc_tb):
         if self.locale:
@@ -103,15 +102,17 @@ class DTInput(InputType[T], ABC):
 
 
 class DTFormatMode(MissingMixin, Enum):
+    # fmt: off
     FULL = 'full'                   #: The full name of a given date/time unit
     ABBREVIATION = 'abbreviation'   #: The abbreviation of a given date/time unit
     NUMERIC = 'numeric'             #: The numeric representation of a given date/time unit
     NUMERIC_ISO = 'numeric_iso'     #: The ISO numeric representation of a given date/time unit
+    # fmt: on
 
 
 class CalendarUnitInput(DTInput[Union[str, int]], ABC):
     __slots__ = ('full', 'abbreviation', 'numeric', 'out_format', 'out_locale')
-    _formats: Dict[DTFormatMode, Sequence[Union[str, int]]]
+    _formats: dict[DTFormatMode, Sequence[Union[str, int]]]
     _min_index: int = 0
 
     def __init_subclass__(cls, min_index: int = 0, **kwargs):
@@ -151,7 +152,7 @@ class CalendarUnitInput(DTInput[Union[str, int]], ABC):
         if self.out_format not in self._formats:
             raise ValueError(f'Unsupported out_format={self.out_format} for {self.__class__.__name__} inputs')
 
-    def _values(self) -> Iterator[Tuple[int, str]]:
+    def _values(self) -> Iterator[tuple[int, str]]:
         if not self.full and not self.abbreviation:
             return
         min_index = self._min_index
@@ -212,13 +213,13 @@ class CalendarUnitInput(DTInput[Union[str, int]], ABC):
         normalized = self.parse(value)
         if normalized < self._min_index:
             raise InvalidChoiceError(value, self.choices(), self.dt_type)
-        elif (out_mode := self.out_format) in (DTFormatMode.NUMERIC, DTFormatMode.NUMERIC_ISO):
-            return self._formats[out_mode][normalized]
-        elif (names_or_abbreviations := self._formats.get(out_mode)) is not None:
+        elif self.out_format in (DTFormatMode.NUMERIC, DTFormatMode.NUMERIC_ISO):
+            return self._formats[self.out_format][normalized]
+        elif (names_or_abbreviations := self._formats.get(self.out_format)) is not None:
             with different_locale(self.out_locale):
                 return names_or_abbreviations[normalized]
 
-        raise ValueError(f'Unexpected output format={out_mode!r} for {self.dt_type}={normalized}')
+        raise ValueError(f'Unexpected output format={self.out_format!r} for {self.dt_type}={normalized}')
 
 
 class Day(CalendarUnitInput, dt_type='day of the week'):
