@@ -7,12 +7,12 @@ ChoiceMap Parameters
 from __future__ import annotations
 
 from functools import partial
-from string import whitespace, printable
-from typing import Type, TypeVar, Generic, Optional, Callable, Union, Collection, Mapping, NoReturn, Dict
+from string import printable, whitespace
 from types import MethodType
+from typing import Callable, Collection, Generic, Mapping, NoReturn, Optional, Type, TypeVar, Union
 
 from ..context import ctx
-from ..exceptions import ParameterDefinitionError, BadArgument, InvalidChoice, CommandDefinitionError
+from ..exceptions import BadArgument, CommandDefinitionError, InvalidChoice, ParameterDefinitionError
 from ..formatting.utils import format_help_entry
 from ..nargs import Nargs
 from ..typing import Bool, CommandCls, CommandObj
@@ -51,9 +51,9 @@ class Choice(Generic[T]):
     def format_usage(self) -> str:
         return '(default)' if self.choice is None else self.choice
 
-    def format_help(self, lpad: int = 4, tw_offset: int = 0, prefix: str = '') -> str:
+    def format_help(self, lpad: int = 4, prefix: str = '') -> str:
         # Note: no longer called by formatters
-        return format_help_entry((self.format_usage(),), self.help, prefix, tw_offset, lpad=lpad)
+        return format_help_entry((self.format_usage(),), self.help, prefix, lpad=lpad)
 
 
 class ChoiceMap(BasePositional[str], Generic[T], actions=(Concatenate,)):
@@ -78,7 +78,7 @@ class ChoiceMap(BasePositional[str], Generic[T], actions=(Concatenate,)):
     _choice_validation_exc = ParameterDefinitionError
     _default_title: str = 'Choices'
     nargs = Nargs('+')
-    choices: Dict[str, Choice[T]]
+    choices: dict[str, Choice[T]]
     title: OptStr
     description: OptStr
 
@@ -135,7 +135,11 @@ class ChoiceMap(BasePositional[str], Generic[T], actions=(Concatenate,)):
         self._register_choice(choice, target, help)
 
     def _register_choice(
-        self, choice: OptStr, target: Optional[T] = _NotSet, help: str = None, local: bool = False  # noqa
+        self,
+        choice: OptStr,
+        target: Optional[T] = _NotSet,
+        help: str = None,  # noqa
+        local: bool = False,
     ):
         try:
             existing = self.choices[choice]
@@ -256,7 +260,11 @@ class SubCommand(ChoiceMap[CommandCls], title='Subcommands', choice_validation_e
         return command
 
     def register(
-        self, command_or_choice: Union[str, CommandCls] = None, *, choice: str = None, help: str = None  # noqa
+        self,
+        command_or_choice: Union[str, CommandCls] = None,
+        *,
+        choice: str = None,
+        help: str = None,  # noqa
     ) -> Callable[[CommandCls], CommandCls]:
         """
         Class decorator version of :meth:`.register_command`.  Registers the wrapped :class:`.Command` as the
@@ -297,7 +305,11 @@ class Action(ChoiceMap[MethodType], title='Actions'):
     """
 
     def register_action(
-        self, choice: OptStr, method: MethodType, help: str = None, default: Bool = False  # noqa
+        self,
+        choice: OptStr,
+        method: MethodType,
+        help: str = None,  # noqa
+        default: Bool = False,
     ) -> MethodType:
         if help is None:
             try:
